Welcome
=======

This welcome component acts as the base (think scaffolding) for all "welcome messages" used for my-sites. It is intentionally bare in order to allow individual sections fine grain control over what the message actually says.

The two pieces of included functionality are: visibility control via a close button and an optional callback function to be run at the time of close.


## Example

This is an example of creating a `welcome-message.jsx` component within a section.

*Adapted from `client/my-sites/posts/welcome-message.jsx`*

```javascript
var React = require( 'react' ),
  store = require( 'store' ),
  user = require( 'lib/user' )(),
  Welcome = require( 'my-sites/welcome/welcome' );

module.exports = React.createClass( {

  buildWelcomeContent: function() {
    var exampleExtra = ( <p className"legend"><span className="noticon noticon-info"></span> You can use any function to build out `WelcomeContent`</p> );

    return (
      <div>
        <h3 className="welcome-section-title" tabIndex="0">{ this.translate( 'Welcome to the New Posts Page' ) }</h3>
        <p><img src="/calypso/images/posts/illustration-posts.svg" className="welcome-intro-illustration" />{ this.translate( "Example introduction message introducing the new hotness." ) }</p>
        { exampleExtra }
      </div>
    );
  },

  closeWelcomeMessage: function() {
    store.set( 'hideExampleWelcome', true );
  },

  render: function() {
    var currentUser = user.get(),
    showWelcome = ! store.get( 'hideExampleWelcome' );

    return (
      <Welcome isVisible={ showWelcome } closeAction={ this.closeWelcomeMessage }>
        { this.buildWelcomeContent() }
      </Welcome>
    );
  }

} );
```

## Properties

Property  | Description
------------- | -------------
`welcomeContent` (jsx, string, etc.) | Any content you wish to display within the welcome container
`isVisible` (boolean) | Controls initial visibility of welcome message
`closeAction` (function) | Optional callback that will run after user closes the message
`additionalClassName` (string) | Optional classes that will be added to base `.welcome-message`

## Styles

Default styles are available in `assets/stylesheets/shared/_welcome.scss`, the main includes are:

- `.welcome-section-title`: Usually an `<h3>` that acts as the welcome message title.
- `.welcome-intro-illustration`: Images that usually accompany the welcome message.
